@@ -3,15 +3,16 @@ import re
 
 class SideStep:
 
-    def __init__(self, step, pipeline_id):
+    def __init__(self, step, pipeline_id, globals):
         self.step = step
         self.pipeline_id = pipeline_id
+        self.globals = globals
 
         if self.pipeline_id:
-            exec(self.step, globals())
+            exec(self.step, self.globals)
         else:
             self.side_step = self.dlt_removal()
-            exec(self.side_step, globals())
+            exec(self.side_step, self.globals)
             print(self.side_step)
 
     def dlt_removal(self):
